{

    /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\
    *                                                                 *
    *   Copyrightcillas 1.0.3                                         *
    *   Copyright  2004  Florian Oldach <oldach@hartwork.org>        *
    *                     Sebastian Pipping <pipping@hartwork.org>    *
    *                                                                 *
    *   --> http://www.hartwork.org                                   *
    *                                                                 *
    *                                                                 *
    *   This source code is released under LGPL.                      *
    *   See LGPL.txt for details.                        2004-09-01   *
    *                                                                 *
    \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

}

UNIT crc_intr;

{ ----------------------------------------------------------------------------------------------------- INTERFACE ----- }
INTERFACE

  USES
    crt,
    crc_std;

  PROCEDURE intro;


{ ------------------------------------------------------------------------------------------------ IMPLEMENTATION ----- }
IMPLEMENTATION

{ -------------------------------------------------------------------------------------------------- message_show ----- }
  PROCEDURE message_show( bVisible : BOOLEAN );
    CONST
      TEXT_INFO  = 'Press a key to continue...';
      TEXT_CLEAR = '                          ';

    BEGIN
      GOTOXY( ( SCREEN_WIDTH - LENGTH( TEXT_INFO ) ) DIV 2 + 1, SCREEN_HEIGHT - 1 );

      IF bVisible THEN
        WRITE( TEXT_INFO )
      ELSE
        WRITE( TEXT_CLEAR );

    END;


{ ------------------------------------------------------------------------------------------------- wait_keypress ----- }
  PROCEDURE wait_keypress;
    CONST
      DISPLAY_LENGTH   = 500;
      FADE_SPEED       = 90;
      FRAME_PAUSE      = 400;

    VAR
      iStep     : BYTE;
      iPart     : BYTE;
      iPartTime : WORD;

    BEGIN
      empty_buffer;
      WHILE TRUE DO
        BEGIN
          FOR iStep := 1 TO 4 DO
            BEGIN
              message_show( FALSE );

              CASE iStep OF

                1:
                  BEGIN
                    { Pause between two frames }
                    iPartTime := FRAME_PAUSE DIV 10;
                    FOR iPart := 1 TO 10 DO
                      BEGIN
                        IF KEYPRESSED THEN EXIT;
                        DELAY( iPartTime );

                      END;

                  END;

                2, 4:
                  BEGIN
                    { Fade in/out }
                    message_show( TRUE );

                    iPartTime := FADE_SPEED DIV 10;
                    FOR iPart := 1 TO 10 DO
                      BEGIN
                        IF KEYPRESSED THEN EXIT;
                        DELAY( iPartTime );

                      END;

                  END;

                3:
                  BEGIN
                    { Display }
                    TEXTCOLOR( WHITE );
                    message_show( TRUE );
                    TEXTCOLOR( LIGHTGRAY );

                    iPartTime := DISPLAY_LENGTH DIV 10;
                    FOR iPart := 1 TO 10 DO
                      BEGIN
                        IF KEYPRESSED THEN EXIT;
                        DELAY( iPartTime );

                      END;

                  END;

              END; { CASE }

            END; { FOR }

        END; { WHILE }

    END;


{ --------------------------------------------------------------------------------------------------------- intro ----- }
  PROCEDURE intro;
    CONST
      INTRO_LEN = 65;
      TEXT_LEFT = ( SCREEN_WIDTH - INTRO_LEN ) DIV 2 + 1;
      TEXT_TOP  = ( 25 - 7 ) DIV 2 + 1;


    VAR
      intro_text : ARRAY[ 0..6 ] OF STRING[ 65 ];
      i, j, k, l : BYTE;
      iLen       : BYTE;
      temp       : STRING[ 7 ];

    BEGIN
      intro_text[ 0 ] := '                                                           ';
      intro_text[ 1 ] := '                                                             ';
      intro_text[ 2 ] := '                     ';
      intro_text[ 3 ] := '                                       ';
      intro_text[ 4 ] := '                   ';
      intro_text[ 5 ] := '                                                              ';
      intro_text[ 6 ] := '                                                           ';

      CLRSCR;

      { Empty keyboard buffer }
      empty_buffer;

      { Each vertical line }
      iLen := LENGTH( intro_text[ 1 ] );
      FOR i := 1 TO iLen DO
        BEGIN

          { Skip empty line (between letters...) }
          temp := '';
          FOR l := 0 TO 6 DO
            temp := temp + intro_text[ l ][ i ];

          IF ( temp <> '       ') THEN
            BEGIN

              { Shift in vertical }
              FOR j := i TO SCREEN_WIDTH - TEXT_LEFT + 1 DO
                BEGIN

                  { Quit on keypress }
                  IF KEYPRESSED THEN
                    EXIT;

                  { Paint new and delete old vertical }
                  FOR k := 0 TO 6 DO
                    BEGIN
                      GOTOXY( SCREEN_WIDTH - j + i, TEXT_TOP + k );
                      WRITE( intro_text[ k ][ i ], ' ' );

                    END;

                  { Animation speed }
                  DELAY( 5 );

                END;

            END;

        END;

      wait_keypress;

    END;


{ ---------------------------------------------------------------------------------------------------------- INIT ----- }
BEGIN END.
