{

    /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *\
    *                                                                 *
    *   Copyrightcillas 1.0.3                                         *
    *   Copyright  2004  Florian Oldach <oldach@hartwork.org>        *
    *                     Sebastian Pipping <pipping@hartwork.org>    *
    *                                                                 *
    *   --> http://www.hartwork.org                                   *
    *                                                                 *
    *                                                                 *
    *   This source code is released under LGPL.                      *
    *   See LGPL.txt for details.                        2004-09-01   *
    *                                                                 *
    \* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

}

UNIT crc_set;

{ ----------------------------------------------------------------------------------------------------- INTERFACE ----- }
INTERFACE

  USES
    crt,
    crc_std;

  CONST
    MODE_NORMAL  = 0;
    MODE_BATTLE  = 1;
    MODE_MEAN    = 2;

    MAX_COOKIES  = 200;

  TYPE
    tSettings = RECORD
      Controls       : ARRAY[ 0..MAX_CONTROLS ] OF CHAR; { U-R-D-L / U-R-D-L }
      iPlayers       : BYTE;
      bSolidSnakes   : BOOLEAN;   { TRUE: SOLID, FALSE: BONES }
      iMap           : BYTE;
      iSpeed         : BYTE;

      iMode          : BYTE;
      iRoundIndex    : BYTE;
      iMultiCookies  : BYTE;

    END;

  VAR
    g_Settings  : tSettings;
    g_iRounds   : ARRAY[ 1..4 ] OF BYTE;

  FUNCTION  read_settings : BOOLEAN;
  PROCEDURE save_settings;


{ ------------------------------------------------------------------------------------------------ IMPLEMENTATION ----- }
IMPLEMENTATION

  VAR
    fSettings : FILE OF tSettings;


{ ---------------------------------------------------------------------------------------------- default_settings ----- }
  PROCEDURE default_settings;
    BEGIN
      WITH g_Settings DO
        BEGIN
          Controls[  0 ] := KEY_UP;
          Controls[  1 ] := KEY_RIGHT;
          Controls[  2 ] := KEY_DOWN;
          Controls[  3 ] := KEY_LEFT;

          Controls[  4 ] := #119; {w}
          Controls[  5 ] := #100; {d}
          Controls[  6 ] := #115; {s}
          Controls[  7 ] := #97;  {a}

          Controls[  8 ] := '8';  {8}
          Controls[  9 ] := '6';  {6}
          Controls[ 10 ] := '5';  {5}
          Controls[ 11 ] := '4';  {4}

          Controls[ 12 ] := 'i';  {i}
          Controls[ 13 ] := 'l';  {l}
          Controls[ 14 ] := 'k';  {k}
          Controls[ 15 ] := 'j';  {j}

          iPlayers       := 1;
          bSolidSnakes   := TRUE;
          iMap           := 2; { (n+1)th map }
          iSpeed         := 7;

          iMode          := MODE_NORMAL;
          iRoundIndex    := 2; { 3 Rounds }
          iMultiCookies  := 0; { Map defined }

        END;

    END;


{ ------------------------------------------------------------------------------------------------ check_settings ----- }
  FUNCTION check_settings : BOOLEAN;
    VAR
      i, j : BYTE;
      bError : BOOLEAN;

    BEGIN
      i := 0;
      bError := FALSE;
      WHILE ( i < MAX_CONTROLS ) AND NOT bError DO
        BEGIN
          { Valid key? }
          CASE g_Settings.Controls[ i ] OF
            '0'..'9', 'a'..'z', 'G', 'O', 'I', 'Q', 'R', 'S', 'K', 'M', 'H', 'P':
          ELSE
            bError := TRUE;
          END;

          { Key used more than one time? }
          j := i + 1;
          WHILE ( j <= MAX_CONTROLS ) AND NOT bError DO
            BEGIN
              IF ( g_Settings.Controls[ i ] = g_Settings.Controls[ j ] ) THEN
                bError := TRUE;

              INC( j );

            END;

          INC( i );

        END;

      IF NOT bError THEN
        BEGIN
          IF NOT between( g_Settings.iPlayers, 1, MAX_PLAYERS ) THEN
            bError := TRUE;
          IF NOT between( g_Settings.iSpeed, 1, 10 ) THEN
            bError := TRUE;
          IF NOT between( g_Settings.iMode, MODE_NORMAL, MODE_MEAN ) THEN
            bError := TRUE;
          IF NOT between( g_Settings.iRoundIndex, 1, 4 ) THEN
            bError := TRUE;
          IF NOT between( g_Settings.iMultiCookies, 0, MAX_COOKIES ) THEN
            bError := TRUE;

        END;

      IF bError THEN
        default_settings;

      check_settings := NOT bError;

    END;


{ ------------------------------------------------------------------------------------------------- read_settings ----- }
  FUNCTION read_settings : BOOLEAN;
    BEGIN
      {$I-}
      RESET( fSettings );
      {$I+}

      IF ( IORESULT <> 0 ) THEN
        BEGIN
          default_settings;
          read_settings := FALSE;

        END
      ELSE
        BEGIN
          IF ( FILESIZE( fSettings ) > 0 ) THEN
            BEGIN
              SEEK( fSettings, 0 );
              READ( fSettings, g_Settings );
              read_settings := check_settings;

            END
          ELSE
            BEGIN
              default_settings;
              read_settings := FALSE;

            END;

          CLOSE( fSettings );

        END;

    END;


{ ------------------------------------------------------------------------------------------------- save_settings ----- }
  PROCEDURE save_settings;
    BEGIN
      {$I-}
      REWRITE( fSettings );
      {$I+}

      IF ( IORESULT = 0 ) THEN
        BEGIN
          WRITE( fSettings, g_Settings );
          CLOSE( fSettings );

        END;

    END;


{ ---------------------------------------------------------------------------------------------------------- INIT ----- }
BEGIN
  ASSIGN( fSettings, FILE_SETTINGS );

  g_iRounds[ 1 ] := 1;
  g_iRounds[ 2 ] := 3;
  g_iRounds[ 3 ] := 5;
  g_iRounds[ 4 ] := 9;

END.